@@ -346,8 +346,6 @@ fail:
 static int d3d12va_encode_av1_get_buffer_size(AVCodecContext *avctx,
                                               D3D12VAEncodePicture *pic, size_t *size)
 {
-    D3D12VAEncodeContext                                    *ctx = avctx->priv_data;
-    D3D12_VIDEO_ENCODER_OUTPUT_METADATA                    *meta = NULL;
     D3D12_VIDEO_ENCODER_FRAME_SUBREGION_METADATA *subregion_meta = NULL;
     uint8_t                                                *data = NULL;
     HRESULT                                                   hr = S_OK;
@@ -383,7 +381,6 @@ static int d3d12va_encode_av1_get_coded_data(AVCodecContext *avctx,
     size_t    av1_pic_hd_size = 0;
     int tile_group_extra_size = 0;
     size_t            bit_len = 0;
-    D3D12VAEncodeContext *ctx = avctx->priv_data;
 
     char pic_hd_data[MAX_PARAM_BUFFER_SIZE] = { 0 };
 
@@ -428,7 +425,7 @@ static int d3d12va_encode_av1_get_coded_data(AVCodecContext *avctx,
     memcpy(ptr, pic_hd_data, av1_pic_hd_size);
     ptr += av1_pic_hd_size;
     total_size -= av1_pic_hd_size;
-    av_log(avctx, AV_LOG_DEBUG, "AV1 total_size after write picture header: %d.\n", total_size);
+    av_log(avctx, AV_LOG_DEBUG, "AV1 total_size after write picture header: %zu.\n", total_size);
 
     total_size -= tile_group_extra_size;
     err = d3d12va_encode_av1_write_tile_group(avctx, mapped_data, total_size, ptr, &bit_len);
@@ -559,7 +556,7 @@ static int d3d12va_encode_av1_init_sequence_params(AVCodecContext *avctx)
         .Codec                            = D3D12_VIDEO_ENCODER_CODEC_AV1,
         .InputFormat                      = hwctx->format,
         .RateControl                      = ctx->rc,
-        .IntraRefresh                     = D3D12_VIDEO_ENCODER_INTRA_REFRESH_MODE_NONE,
+        .IntraRefresh                     = ctx->intra_refresh.Mode,
         .SubregionFrameEncoding           = D3D12_VIDEO_ENCODER_FRAME_SUBREGION_LAYOUT_MODE_FULL_FRAME,
         .ResolutionsListCount             = 1,
         .pResolutionList                  = &ctx->resolution,
@@ -995,9 +992,7 @@ static int d3d12va_encode_av1_init_picture_params(AVCodecContext *avctx,
             d3d12va_pic->pic_ctl.pAV1PicData->ReferenceIndices[i] = fh->ref_frame_idx[i];
     }
 
-    int ret = av_fifo_write(priv->picture_header_list, &priv->units.raw_frame_header, 1);
-
-    return 0;
+    return av_fifo_write(priv->picture_header_list, &priv->units.raw_frame_header, 1);
 }
 
 
@@ -1082,6 +1077,7 @@ static int d3d12va_encode_av1_close(AVCodecContext *avctx)
 #define FLAGS (AV_OPT_FLAG_VIDEO_PARAM | AV_OPT_FLAG_ENCODING_PARAM)
 static const AVOption d3d12va_encode_av1_options[] = {
     HW_BASE_ENCODE_COMMON_OPTIONS,
+    D3D12VA_ENCODE_COMMON_OPTIONS,
     D3D12VA_ENCODE_RC_OPTIONS,
 
     { "qp", "Constant QP (for P-frames; scaled by qfactor/qoffset for I/B)",
